Learn R Programming

G2Sd (version 2.2)

grandistrib: Composition of the sediment

Description

This function provides a barplot of the different fractions composing the sediment

Usage

grandistrib(x, main="", scale = "fine", xlab = "Stations", ylab = "Percentage")

Value

A barplot with the composition of sediment for each station sampled

Arguments

x

A numeric matrix or data frame (see the shape of data(granulo))

main

a label for the title

scale

If fine, display the detailed composition; If large, display the simplify composition

xlab

a label for the x axis, defaults to a description of x.

ylab

a label for the y axis, defaults to a description of y.

Author

Regis K. Gallon (CNAM-Intechmer)
regis.gallon@lecnam.net

Details

The obtained graph is commonly used by Sedimentologists

See Also

granplot, grandistrib

Examples

Run this code
data(granulo)
grandistrib(granulo, scale="fine")

Run the code above in your browser using DataLab