powered by
This function provides a barplot of the different fractions composing the sediment
grandistrib(x, main="", scale = "fine", xlab = "Stations", ylab = "Percentage")
A barplot with the composition of sediment for each station sampled
A numeric matrix or data frame (see the shape of data(granulo))
a label for the title
If fine, display the detailed composition; If large, display the simplify composition
a label for the x axis, defaults to a description of x.
a label for the y axis, defaults to a description of y.
Regis K. Gallon (CNAM-Intechmer) regis.gallon@lecnam.net
The obtained graph is commonly used by Sedimentologists
granplot, grandistrib
granplot
grandistrib
data(granulo) grandistrib(granulo, scale="fine")
Run the code above in your browser using DataLab